@@ -257,7 +257,7 @@ def _getDatatype (dataTypeEnum):
     5: ("b",1), #signed char (SByte)
     6: ("B",1), #unsigned char (Byte)
 	7: ("h",2), #short (Int16)
-	8: ("H",4), #unsigned char (UInt16)
+	8: ("H",2), #unsigned short (UInt16)
 	9: ("i",4), #int (Int32)
 	10: ("I",4), #unsigned int (UInt32)
 	11: ("q",8), #long long (Int64)
@@ -707,7 +707,7 @@ def binFileToDF(path, extension=None):
     logData._fileName = os.path.basename(path)
     
     if extension == None:
-        if '.' not in logData._fileType:
+        if '.' not in file_extension:
             print("Warning, unidentified file extension, assuming .bin")
             file_extension = '.bin'
             
