@@ -81,6 +81,9 @@ def rphToDf(path):
         values.append(row)
         
     time_stamp_count = int.from_bytes(bytesStream.read(2), "little", signed = False)
+        
+    if number_of_samples > 65535:
+        time_stamp_count =  int.from_bytes(bytesStream.read(4), "little", signed = False)
     
     for timestamp in range(time_stamp_count):
         total_seconds = bytesStream.read(4) #time_t.TotalSeconds
